List of Relevant Similar Projects
=================================

.. list-table:: Photonic Simulation Tools and Their Status
   :header-rows: 1

   * - Name
     - Description
     - Status
   * - `Simphony <https://github.com/BYUCamachoLab/simphony>`__
     - A simulator for photonic integrated circuits.
     - Active
   * - `PhotonFlux <https://github.com/alexsludds/photonflux>`__
     - Photonic circuit network simulator.
     - Unclear
   * - `Photontorch <https://github.com/flaport/photontorch>`__
     - Highly parallel simulation and optimization of photonic circuits in time and frequency domain based on the deep-learning framework PyTorch.
     - Maintenance
